<?php
/*
  Plugin Name: WP Simple Galleries
  Version: 0.1
  Description: A simple plugin that adds an image gallery to each post and page.
  Plugin URI: http://maca134.co.uk/blog/wp-simple-galleries/
  Author: Matthew McConnell
  Author URI: http://maca134.co.uk/
 */

$plugin_dir = plugin_basename(__FILE__);
$plugin_dir = str_replace(basename($plugin_dir), '', $plugin_dir);
define('WPSIMPLEGALLERY_DIR', WP_PLUGIN_DIR . '/' . $plugin_dir);
define('WPSIMPLEGALLERY_URL', WP_PLUGIN_URL . '/' . $plugin_dir);
define('WPSIMPLEGALLERY_DEBUG', true);

if (!function_exists('optionsframework_init')) {
    define('OPTIONS_FRAMEWORK_URL', WPSIMPLEGALLERY_URL . 'admin/');
    define('OPTIONS_FRAMEWORK_DIRECTORY', WPSIMPLEGALLERY_DIR . 'admin/');
    define('OPTIONS_FRAMEWORK_NAME', 'Simple Gallery');
    define('OPTIONS_FRAMEWORK_TAG', 'wpsimplegallery');
    require_once (OPTIONS_FRAMEWORK_DIRECTORY . 'options-framework.php');
}

class wpsimplegallery {

    private static $instance;
    private $admin_thumbnail_size = 109;
    private $thumbnail_size_w = 150;
    private $thumbnail_size_h = 150;

    public static function forge() {
        if (!isset(self::$instance)) {
            $className = __CLASS__;
            self::$instance = new $className;
        }
        return self::$instance;
    }

    private function __construct() {
        $this->thumbnail_size_w = of_get_option('wpsimplegallery_thumb_width');
        $this->thumbnail_size_h = of_get_option('wpsimplegallery_thumb_height');
        
        add_action('admin_print_scripts-post.php', array(&$this, 'admin_print_scripts'));
        add_action('admin_print_scripts-post-new.php', array(&$this, 'admin_print_scripts'));
        add_action('admin_print_styles-post.php', array(&$this, 'admin_print_styles'));
        add_action('admin_print_styles-post-new.php', array(&$this, 'admin_print_styles'));
        add_action('wp_print_scripts', array(&$this, 'print_scripts'));
        add_action('wp_print_styles', array(&$this, 'print_styles'));
        add_filter('the_content', array(&$this, 'output_gallery'));
        add_image_size('wpsimplegallery_admin_thumb', $this->admin_thumbnail_size, $this->admin_thumbnail_size, true);
        add_image_size('wpsimplegallery_thumb', $this->thumbnail_size_w, $this->thumbnail_size_h, true);
        if (is_admin()) {
            add_action('wp_ajax_wpsimplegallery_get_thumbnail', array(&$this, 'ajax_get_thumbnail'));
            add_action('add_meta_boxes', array(&$this, 'add_meta_boxes'));
            add_action('admin_init', array(&$this, 'add_meta_boxes'), 1);
            add_action('save_post', array(&$this, 'save_post_meta'));
        }
    }

    public function admin_print_scripts() {
        wp_enqueue_script('media-upload');
        wp_enqueue_script('wpsimplegallery-admin-scripts', WPSIMPLEGALLERY_URL . 'wp-simple-gallery-admin.js', array('jquery'));
    }

    public function admin_print_styles() {
        wp_enqueue_style('wpsimplegallery-admin-style', WPSIMPLEGALLERY_URL . 'wp-simple-gallery-admin.css');
    }

    public function add_meta_boxes() {
        add_meta_box(
                'wpsimplegallery', __('WP Simple Gallery', 'wpsimplegallery'), array(&$this, 'inner_custom_box'), 'post'
        );
        add_meta_box(
                'wpsimplegallery', __('WP Simple Gallery', 'wpsimplegallery'), array(&$this, 'inner_custom_box'), 'page'
        );
    }

    public function inner_custom_box($post) {
        $images = get_post_meta($post->ID, 'wpsimplegallery_gallery');
        ?>
        <input style="width: auto;" id="wpsimplegallery_upload_button" class="upload_button button" type="button" value="<?php echo __('Upload Image', 'wpsimplegallery'); ?>" rel="" />
        <div id="wpsimplegallery_container">
            <ul id="wpsimplegallery_thumbs" class="clearfix"><?php
        if (isset($images[0]) && count($images[0]) > 0) {
            foreach ($images[0] as $id) {
                echo $this->admin_thumb($id);
            }
        }
        ?></ul>
        </div>
        <?php
    }

    public function ajax_get_thumbnail() {
        header('Cache-Control: no-cache, must-revalidate');
        header('Expires: Mon, 26 Jul 1997 05:00:00 GMT');
        echo $this->admin_thumb($_POST['imageid']);
        die;
    }

    private function admin_thumb($id) {
        $image = wp_get_attachment_image_src($id, 'wpsimplegallery_admin_thumb', true);
        ?>
        <li><img src="<?php echo $image[0]; ?>" width="<?php echo $image[1]; ?>" height="<?php echo $image[2]; ?>" /><a href="#" class="wpsimplegallery_remove">Remove</a><input type="hidden" name="wpsimplegallery_thumb[]" value="<?php echo $id; ?>" /></li>
        <?php
    }

    private function thumb($id) {
        $image = wp_get_attachment_image_src($id, 'wpsimplegallery_thumb', true);
        return '<li><a href="' . wp_get_attachment_url($id) . '"><img src="' . $image[0] . '" width="' . $image[1] . '" height="' . $image[2] . '" /></a></li>';
    }

    public function save_post_meta($id) {
        if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
            return '';
        }
        $images = (isset($_POST['wpsimplegallery_thumb'])) ? $_POST['wpsimplegallery_thumb'] : array();
        $gallery = array();
        if (count($images) > 0) {
            foreach ($images as $i => $img) {
                $gallery[] = $img;
            }
        }
        update_post_meta($id, 'wpsimplegallery_gallery', $gallery);
    }

    public function print_scripts() {
        //wp_enqueue_script('wpsimplegallery-scripts', WPSIMPLEGALLERY_URL . 'wp-simple-gallery.js', array('jquery', 'jquery-ui-core'));
    }

    public function print_styles() {
        wp_enqueue_style('wpsimplegallery-style', WPSIMPLEGALLERY_URL . 'wp-simple-gallery.css');
    }

    public function output_gallery($content) {
        global $post;
        $gallery = get_post_meta($post->ID, 'wpsimplegallery_gallery', true);
        $html = '';
        if (count($gallery) > 0) {
            $html = '<div id="wpsimplegallery_container"><ul id="wpsimplegallery" class="clearfix">';
            foreach ($gallery as $thumbid) {
                $html .= $this->thumb($thumbid);
            }
            $html .= '</ul></div>';
        }
        return $content . $html;
    }

}

function wpsimplegallery() {
    global $wpsimplegallery;
    $wpsimplegallery = wpsimplegallery::forge();
}

add_action("init", "wpsimplegallery");